==> MEDME_1.10.0.zip: MEDME/doc/MEDME.R <==
###################################################
### chunk number 1: MEDMEload
###################################################
#line 47 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
library(MEDME)
data(testMEDMEset)


###################################################
### chunk number 2: MEDMEdata
###################################################
#line 60 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
logR(testMEDMEset[1:5,])


###################################################
### chunk number 3: MEDMEsmooth
###################################################
#line 67 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
testMEDMEset = smooth(data = testMEDMEset, wsize = 1000, wFunction = 'linear')


###################################################
### chunk number 4: MEDMEcpg
###################################################
#line 77 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
library(BSgenome.Hsapiens.UCSC.hg18)
testMEDMEset = CGcount(data = testMEDMEset)


###################################################
### chunk number 5: MEDMEmodel
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
MEDMEmodel = MEDME(data = testMEDMEset, sample = 1)


###################################################
### chunk number 6: MEDMErun
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
testMEDMEset = predict(data = testMEDMEset, MEDMEfit = MEDMEmodel, MEDMEextremes = c(1,32), wsize = 1000, wFunction='linear')


###################################################
### chunk number 7: MEDMEsee
###################################################
#line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmps3S4ge/R.INSTALL5e8164a0/MEDME/inst/doc/MEDME.rnw"
smoothed(testMEDMEset)[1:3,]
AMS(testMEDMEset)[1:3,]
RMS(testMEDMEset)[1:3,]

==> MEDME_1.12.0.zip: MEDME/doc/MEDME.R <==
###################################################
### chunk number 1: MEDMEload
###################################################
#line 47 "MEDME.rnw"
library(MEDME)
data(testMEDMEset)


###################################################
### chunk number 2: MEDMEdata
###################################################
#line 60 "MEDME.rnw"
logR(testMEDMEset[1:5,])


###################################################
### chunk number 3: MEDMEsmooth
###################################################
#line 67 "MEDME.rnw"
testMEDMEset = smooth(data = testMEDMEset, wsize = 1000, wFunction = 'linear')


###################################################
### chunk number 4: MEDMEcpg
###################################################
#line 77 "MEDME.rnw"
library(BSgenome.Hsapiens.UCSC.hg18)
testMEDMEset = CGcount(data = testMEDMEset)


###################################################
### chunk number 5: MEDMEmodel
###################################################
#line 88 "MEDME.rnw"
MEDMEmodel = MEDME(data = testMEDMEset, sample = 1)


###################################################
### chunk number 6: MEDMErun
###################################################
#line 95 "MEDME.rnw"
testMEDMEset = predict(data = testMEDMEset, MEDMEfit = MEDMEmodel, MEDMEextremes = c(1,32), wsize = 1000, wFunction='linear')


###################################################
### chunk number 7: MEDMEsee
###################################################
#line 102 "MEDME.rnw"
smoothed(testMEDMEset)[1:3,]
AMS(testMEDMEset)[1:3,]
RMS(testMEDMEset)[1:3,]
